import { Component, OnInit } from "@angular/core";
import {
  FormBuilder,
  Validators,
  FormGroup,
  FormControl,
} from "@angular/forms";
import { ActivatedRoute } from "@angular/router";

import { MainService } from "../../services/main.service";
import { ToolService } from "src/app/services/tool.service";

@Component({
  selector: "app-hospital-management",
  templateUrl: "./hospital-management.component.html",
  styleUrls: ["./hospital-management.component.less"],
})
export class HospitalManagementComponent implements OnInit {
  constructor(
    private fb: FormBuilder,
    private mainService: MainService,
    private route: ActivatedRoute,
    private tool: ToolService
  ) {}

  ngOnInit() {
    this.coopBtns = this.tool.initCoopBtns(this.route);
    this.getList();
    this.initForm();
    this.initFormCopy();
  }

  currentUserAccount: any = JSON.parse(localStorage.getItem("user")).user
    .account; //当前登录人账号
  listOfData: any[] = []; //表格数据
  pageIndex: number = 1; //表格当前页码
  pageSize: number = 10; //表格每页展示条数
  listLength: number = 10; //表格总数据量
  modal: boolean = false; //新增/编辑模态框
  modalCopy: boolean = false; //复制模态框
  add: boolean; //true:新增；false:编辑
  validateForm: FormGroup; //新增/编辑表单
  validateFormCopy: FormGroup; //复制表单
  coopId: number; //当前操作列id

  promptContent: string; //操作提示框提示信息
  ifSuccess: boolean; //操作成功/失败
  promptInfo: string; //操作结果提示信息
  promptModalShow: boolean; //操作提示框是否展示

  btnLoading: boolean = false; //确认按钮loading状态

  // 初始化增删改按钮
  coopBtns: any = {};

  // 表格数据
  loading1 = false;
  getList() {
    let data = {
      idx: this.pageIndex - 1,
      sum: this.pageSize,
    };
    this.loading1 = true;
    this.mainService
      .getFetchDataList("data", "hospital", data)
      .subscribe((data) => {
        this.loading1 = false;
        this.listOfData = data.list;
        this.listLength = data.totalNum;
      });
  }

  addModal() {
    this.add = true;
    this.modal = true;
    this.validateForm.controls.hospitalName.setValue("");
    this.validateForm.controls.hospitalNum.setValue("");
  }
  hideAddModal() {
    this.modal = false;
    this.initForm();
  }
  copy(data) {
    this.coopId = data.id;
    this.addModalCopy();
  }
  addModalCopy() {
    this.modalCopy = true;
  }
  hideAddModalCopy() {
    this.modalCopy = false;
    this.initFormCopy();
  }
  // 初始化复制form表单
  initFormCopy() {
    this.validateFormCopy = this.fb.group({
      copyHosId: [null, [Validators.required]],
    });
  }
  // 复制表单提交
  submitFormCopy(): void {
    var that = this;
    for (const i in that.validateFormCopy.controls) {
      that.validateFormCopy.controls[i].markAsDirty();
      that.validateFormCopy.controls[i].updateValueAndValidity();
    }
    if (that.validateFormCopy.invalid) return;
    that.btnLoading = true;
    let data = {
      sourceHosId: this.coopId,
      destHosId: that.validateFormCopy.value.copyHosId,
    };
    that.mainService.copyHosTaskType(data).subscribe((data) => {
      that.btnLoading = false;
      that.hideAddModalCopy();
      if (data["status"] == 200) {
        that.showPromptModal("复制", true, "");
        that.initFormCopy();
      } else {
        that.showPromptModal("复制", false, data["msg"]);
      }
    });
  }
  // 初始化新增form表单
  initForm() {
    this.validateForm = this.fb.group({
      hospitalName: [null, [Validators.required]],
      hospitalNum: [null, [Validators.required]],
    });
  }

  // 新增表单提交
  submitForm(): void {
    var that = this;
    for (const i in that.validateForm.controls) {
      that.validateForm.controls[i].markAsDirty();
      that.validateForm.controls[i].updateValueAndValidity();
    }
    if (that.validateForm.invalid) return;
    that.btnLoading = true;
    let data = {
      hospital: {
        hosName: that.validateForm.value.hospitalName,
        hosNo: that.validateForm.value.hospitalNum,
      },
    };
    if (!that.add) {
      data.hospital["id"] = that.coopId;
    }
    that.mainService
      .coopData(that.add ? "addData" : "updData", "hospital", data)
      .subscribe((data) => {
        that.btnLoading = false;
        that.hideAddModal();
        if (data.status == 200) {
          that.showPromptModal(that.add ? "新增" : "编辑", true, "");
          that.initForm();
        } else {
          that.showPromptModal(that.add ? "新增" : "编辑", false, data.msg);
        }
      });
  }

  // 编辑
  edit(data) {
    this.add = false;
    this.modal = true;
    this.coopId = data.id;
    this.validateForm.controls.hospitalName.setValue(data.hosName);
    this.validateForm.controls.hospitalNum.setValue(data.hosNo);
  }

  delModal: boolean = false; //删除模态框
  showDelModal(id) {
    this.delModal = true;
    this.coopId = id;
  }
  hideDelModal() {
    this.delModal = false;
  }
  confirmDel() {
    this.delModal = false;
    var that = this;
    that.btnLoading = true;
    that.mainService
      .coopData("rmvData", "hospital", [that.coopId])
      .subscribe((data) => {
        that.btnLoading = false;
        if (data.status == 200) {
          if (
            that.listOfData.length == 1 &&
            that.pageIndex == Math.ceil(that.listLength / that.pageSize)
          ) {
            that.listLength--;
            that.pageIndex = Math.ceil(that.listLength / that.pageSize);
          }
          this.showPromptModal("删除", true, "");
        } else {
          this.showPromptModal("删除", false, data.msg);
        }
      });
  }

  // 展示信息提示框（con:提示信息，success:操作是否成功，promptInfo:操作结果提示信息）
  showPromptModal(con, success, promptInfo?) {
    this.promptModalShow = false;
    this.promptContent = con;
    this.ifSuccess = success;
    this.promptInfo = promptInfo;
    setTimeout(() => {
      this.promptModalShow = true;
    }, 100);
    this.getList();
  }
}
